package com.hp.user.client.service;

import com.hp.user.client.entity.AccountPage;
import com.hp.user.client.entity.AccountVO;
import com.hp.user.client.entity.DataResult;

import java.util.List;

/**
 * <p>
 * 用户信息表 服务类
 * </p>
 *
 * @author 王怡静
 * @since 2020-11-20
 */
public interface AccountService {
	public boolean insert(AccountVO account);
	public boolean delete(String userId);
	public boolean update(AccountVO account);
	public AccountPage queryAccountsPageByCompanyIdAndUserNameAndPhoneAndStatus(String companyId,String userName,String phone,Integer status,Long current,Integer size);
	public boolean batchChangeStatusOfUser(String companyId,String[] userIds,Short status);

	/**
	 * 登陆
	 * @param phone 手机号
	 * @param verificationCode 验证码
	 */
	public void login(String phone,String verificationCode);
	
	/**
	 * 判断手机号是否注册过
	 * 注册过返回true
	 * 没有注册过返回false
	 * @param phone
	 */
	public Boolean checkPhone(String phone);
	
	/**
	 * 注册
	 * @param account
	 */
	public void register(AccountVO account);
	
	/**
	 * 绑定微信号
	 * @param userId 用户id
	 * @param wxNumber 微信号
	 */
	public void bindWx(String userId,String wxNumber);
	
	/**
	 * 微信授权登陆
	 */
	public DataResult<AccountVO> wxAuthorization(AccountVO account,String wxCode);
	
	/**
	 * 通过微信注册
	 * @param account
	 * @param verificationCode 验证码
	 * @return
	 */
	public DataResult<AccountVO> wxRegister(AccountVO account,String verificationCode);

}
