package com.hp.user.service.controller;

import com.hp.user.client.entity.AccountPage;
import com.hp.user.client.entity.AccountVO;
import com.hp.user.client.service.AccountService;
import com.hp.user.service.utils.HttpResult;
import com.hp.user.service.utils.IdWorker;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@Api(tags = "账号API接口")
@RestController
@RequestMapping("/user")
public class UserController {
    @Autowired
    private AccountService accountService;

    /**
     * 添加用户
     *
     * @param user 用户信息
     * @return HttpResult
     */
    @ApiOperation(value = "新增账户", notes = "提示：要指定账号对应的服务商", httpMethod = "POST")
    @PostMapping("/addUser")
    public HttpResult addUser(@RequestBody AccountVO user) {
        user.setUserId(IdWorker.generactorId().toString());
        boolean flag = accountService.insert(user);
        if (flag) return HttpResult.success(user.getUserId());
        else return HttpResult.fail("添加失败");
    }

    /**
     * 更新用户信息
     *
     * @param user 用户信息
     * @return HttpResult
     */
    @ApiOperation(value = "更新账户信息")
    @PostMapping("/updateUser")
    public HttpResult updateUser(@RequestBody AccountVO user) {
        boolean flag = accountService.update(user);
        if (flag) return HttpResult.success();
        else return HttpResult.fail("更新失败");
    }

    /**
     * 根据用户Id删除用户
     *
     * @param userId 用户Id
     * @return HttpResult
     */

    @ApiOperation(value = "根据用户Id删除用户")
    @GetMapping("/deleteUserByUserId")
    public HttpResult deleteUserByUserId(String userId) {
        boolean flag = accountService.delete(userId);
        if (flag) return HttpResult.success();
        else return HttpResult.fail("删除失败");
    }

    /**
     * 根据服务商Id、用户姓名、手机号码、启用状态 分页查询账号
     *
     * @param companyId 服务商Id
     * @param userName  用户姓名
     * @param phone     手机号码
     * @param status    启用状态
     * @param current   要查询页数
     * @param size      一页的行数
     * @return HttpResult
     */
    @ApiOperation(value = "根据服务商Id、用户姓名、手机号码、启用状态 分页查询账号", notes = "启用：status=0，禁用：status=1，全部：status为其他数字")
    @GetMapping("/queryAccountsPageByCompanyIdAndUserNameAndPhoneAndStatus")
    public HttpResult queryAccountsPageByCompanyIdAndUserNameAndPhoneAndStatus(@RequestParam String companyId, String userName, String phone, @RequestParam Integer status, @RequestParam Long current, @RequestParam Integer size) {
        AccountPage accountPage = accountService.queryAccountsPageByCompanyIdAndUserNameAndPhoneAndStatus(companyId, userName, phone, status, current, size);
        if (accountPage != null) return HttpResult.success(accountPage);
        else return HttpResult.fail("查询失败");

    }

    /**
     * 批量启用/禁用账号
     * @param companyId 服务商Id
     * @param userIds 用户Id数组
     * @param status 启用状态
     * @return HttpResult
     */
    @ApiOperation(value = "批量启用/禁用账号", notes = "启用：status=0，禁用：status=1")
    @PostMapping("/batchChangeStatusOfUser")
    public HttpResult batchChangeStatusOfUser(@RequestParam  String companyId,@RequestBody String[] userIds,@RequestParam Short status) {
        boolean flag = accountService.batchChangeStatusOfUser(companyId,userIds,status);
        if(flag) return HttpResult.success();
        else return HttpResult.fail();
    }
}
